@@ -28,41 +28,23 @@ FilterCarScore = R6Class("FilterCarScore",
   inherit = Filter,
 
   public = list(
-
     #' @description Create a FilterCarScore object.
-    #' @param id (`character(1)`)\cr
-    #'   Identifier for the filter.
-    #' @param task_type (`character()`)\cr
-    #'   Types of the task the filter can operator on. E.g., `"classif"` or
-    #'   `"regr"`.
-    #' @param param_set ([paradox::ParamSet])\cr
-    #'   Set of hyperparameters.
-    #' @param feature_types (`character()`)\cr
-    #'   Feature types the filter operates on.
-    #'   Must be a subset of
-    #'   [`mlr_reflections$task_feature_types`][mlr3::mlr_reflections].
-    #' @param packages (`character()`)\cr
-    #'   Set of required packages.
-    #'   Note that these packages will be loaded via [requireNamespace()], and
-    #'   are not attached.
-    initialize = function(id = "carscore",
-      task_type = "regr",
+    initialize = function() {
       param_set = ParamSet$new(list(
         ParamDbl$new("lambda", lower = 0, upper = 1, default = NO_DEF),
         ParamLgl$new("diagonal", default = FALSE),
-        ParamLgl$new("verbose", default = TRUE))),
-      packages = "care",
-      feature_types = "numeric") {
+        ParamLgl$new("verbose", default = TRUE))
+      )
+      param_set$values = list(verbose = FALSE)
+
       super$initialize(
-        id = id,
-        task_type = task_type,
+        id = "carscore",
+        task_type = "regr",
         param_set = param_set,
-        feature_types = feature_types,
-        packages = packages,
+        feature_types = "numeric",
+        packages = "care",
         man = "mlr3filters::mlr_filters_carscore"
-
       )
-      self$param_set$values = list(verbose = FALSE)
     }
   ),
 
