@@ -1,13 +1,20 @@
 #' @title Syntactic Sugar for Filter Construction
 #'
 #' @description
-#' This function complements [mlr_filters] with a function in the spirit of [mlr3::mlr_sugar].
+#' These functions complements [mlr_filters] with a function in the spirit of [mlr3::mlr_sugar].
 #'
 #' @inheritParams mlr3::mlr_sugar
 #' @return [Filter].
 #' @export
 #' @examples
 #' flt("correlation", method = "kendall")
+#' flts(c("mrmr", "jmim"))
 flt = function(.key, ...) {
   dictionary_sugar(mlr_filters, .key, ...)
 }
+
+#' @rdname flt
+#' @export
+flts = function(.keys, ...) {
+  dictionary_sugar_mget(mlr_filters, .keys, ...)
+}
